==> ejc-assistrmat-api-3.0.0-20220915.064758-213-sources.jar: com/ejianc/business/assist/material/vo/MaterialContractOtherVO.java <==
package com.ejianc.business.assist.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 辅料中心采购合同-其他费用
 * 
 * @author generator
 * 
 */
public class MaterialContractOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long contractId; // 合同id
    private Long changeId; // 变更表主键
    private Long changeBid; // 变更子表主键
    private String costName; // 费用名称
    private BigDecimal count; // 数量
    private BigDecimal unitPrice; // 单价(无税)
    private BigDecimal unitTaxPrice; // 单价
    private BigDecimal taxRate; // 税率
    private BigDecimal tax; // 税额
    private BigDecimal mny; // 金额(无税)
    private BigDecimal taxMny; // 金额
    private String memo; // 备注
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCount() {
        return count;
    }

    public void setCount(BigDecimal count) {
        this.count = count;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-assistrmat-api-3.0.0-20230531.073911-389-sources.jar: com/ejianc/business/assist/material/vo/MaterialContractOtherVO.java <==
package com.ejianc.business.assist.material.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 辅料中心采购合同-其他费用
 * 
 * @author generator
 * 
 */
public class MaterialContractOtherVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long contractId; // 合同id
    private Long changeId; // 变更表主键
    private Long changeBid; // 变更子表主键
    private String costName; // 费用名称
    private BigDecimal count; // 数量
    private BigDecimal unitPrice; // 单价(无税)
    private BigDecimal unitTaxPrice; // 单价
    private BigDecimal taxRate; // 税率
    private BigDecimal tax; // 税额
    private BigDecimal mny; // 金额(无税)
    private BigDecimal taxMny; // 金额
    private String memo; // 备注

    //模板导出使用
    private String otherPriceStr;
    private String otherTaxPriceStr;
    private String otherMnyStr;
    private String otherTaxMnyStr;
    private String otherTaxStr;
    private String otherNumStr;
    private String otherTaxRateStr;

    public String getOtherPriceStr() {
        return otherPriceStr;
    }

    public void setOtherPriceStr(String otherPriceStr) {
        this.otherPriceStr = otherPriceStr;
    }

    public String getOtherTaxPriceStr() {
        return otherTaxPriceStr;
    }

    public void setOtherTaxPriceStr(String otherTaxPriceStr) {
        this.otherTaxPriceStr = otherTaxPriceStr;
    }

    public String getOtherMnyStr() {
        return otherMnyStr;
    }

    public void setOtherMnyStr(String otherMnyStr) {
        this.otherMnyStr = otherMnyStr;
    }

    public String getOtherTaxMnyStr() {
        return otherTaxMnyStr;
    }

    public void setOtherTaxMnyStr(String otherTaxMnyStr) {
        this.otherTaxMnyStr = otherTaxMnyStr;
    }

    public String getOtherTaxStr() {
        return otherTaxStr;
    }

    public void setOtherTaxStr(String otherTaxStr) {
        this.otherTaxStr = otherTaxStr;
    }

    public String getOtherNumStr() {
        return otherNumStr;
    }

    public void setOtherNumStr(String otherNumStr) {
        this.otherNumStr = otherNumStr;
    }

    public String getOtherTaxRateStr() {
        return otherTaxRateStr;
    }

    public void setOtherTaxRateStr(String otherTaxRateStr) {
        this.otherTaxRateStr = otherTaxRateStr;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public String getCostName() {
        return costName;
    }

    public void setCostName(String costName) {
        this.costName = costName;
    }
    public BigDecimal getCount() {
        return count;
    }

    public void setCount(BigDecimal count) {
        this.count = count;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public BigDecimal getUnitTaxPrice() {
        return unitTaxPrice;
    }

    public void setUnitTaxPrice(BigDecimal unitTaxPrice) {
        this.unitTaxPrice = unitTaxPrice;
    }
    public BigDecimal getTaxRate() {
        return taxRate;
    }

    public void setTaxRate(BigDecimal taxRate) {
        this.taxRate = taxRate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxMny() {
        return taxMny;
    }

    public void setTaxMny(BigDecimal taxMny) {
        this.taxMny = taxMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
